@@ -1,7 +1,6 @@
 from flask import Flask
 from flask_sqlalchemy import SQLAlchemy
-from flask_script import Manager
-from flask_migrate import Migrate, MigrateCommand
+from flask_migrate import Migrate
 
 app = Flask(__name__)
 app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///app.db'
@@ -10,14 +9,18 @@ app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
 db = SQLAlchemy(app)
 migrate = Migrate(app, db, directory='temp_folder/temp_migrations')
 
-manager = Manager(app)
-manager.add_command('db', MigrateCommand)
-
 
 class User(db.Model):
     id = db.Column(db.Integer, primary_key=True)
     name = db.Column(db.String(128))
 
 
+@app.cli.command()
+def add():
+    """Add test user."""
+    db.session.add(User(name='test'))
+    db.session.commit()
+
+
 if __name__ == '__main__':
-    manager.run()
+    app.run()
